<?php

namespace Drupal\cas_server;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Generate dynamic permissions for CAS services.
 */
class CasServerPermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * CasServerPermissions constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('entity_type.manager'));
  }

  /**
   * Returns an array of permissions for sign in with available services.
   *
   * @return array
   *   The permissions.
   *   @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function servicePermissions() {
    $permissions = [];

    $services = $this->entityTypeManager
      ->getStorage('cas_server_service')
      ->loadMultiple();
    foreach ($services as $service) {
      $permissions["cas server login to {$service->id()} service"] = [
        'title' => $this->t('Allow CAS login to %service_name service', [
          '%service_name' => $service->label(),
        ]),
      ];
    }

    return $permissions;
  }

}
